@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the AcousticBrainz API
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -80,7 +80,7 @@ WebService::AcousticBrainz - Access to the AcousticBrainz API
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -121,9 +121,9 @@ B<query> arguments.
 
 L<Moo>
 
-L<use Mojo::UserAgent>
+L<Mojo::UserAgent>
 
-L<use Mojo::JSON::MaybeXS>
+L<Mojo::JSON::MaybeXS>
 
 L<https://acousticbrainz.org/data>
 
